==> modx-2.0.7-pl-ja.zip: modx-2.0.7-pl-ja/core/lexicon/ja/system_info.inc.php <==
<?php
/**
 * System Info Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author Nick http://smallworld.west-tokyo.com
 * @author shimojo http://www.priqia.com/
 * @author yamamoto http://kyms.jp
 */
$_lang['database_charset'] = 'データベース文字コード';
$_lang['database_name'] = 'データベース名';
$_lang['database_server'] = 'データベースサーバー';
$_lang['database_tables'] = 'テーブル一覧';
$_lang['database_optimize'] = 'Optimize Database';
$_lang['database_overhead'] = '<strong style=\'color:#990033\'>注:</strong>オーバーヘッドとは、確保されているが使われていない領域のことです。オーバーヘッドの数字をクリックすると、この領域を開放します';
$_lang['database_table_clickhere'] = 'ここをクリック';
$_lang['database_table_clickbackup'] = '選択したテーブルをバックアップ・ダウンロード';
$_lang['database_table_datasize'] = 'データサイズ';
$_lang['database_table_droptablestatements'] = 'DROP文を生成';
$_lang['database_table_effectivesize'] = '有効サイズ';
$_lang['database_table_indexsize'] = 'インデックス';
$_lang['database_table_overhead'] = 'オーバーヘッド';
$_lang['database_table_records'] = '件数';
$_lang['database_table_tablename'] = 'テーブル名';
$_lang['database_table_totalsize'] = '合計サイズ';
$_lang['database_table_totals'] = '総計:';
$_lang['database_type'] = 'データベースの種類';
$_lang['database_version'] = 'データベースのバージョン:';
$_lang['extjs_version'] = '<a href="http://extjs.com/" target="_blank">ExtJS</a> のバージョン';
$_lang['localtime'] = 'ローカル時刻';
$_lang['magpie_version'] = '<a href="http://magpierss.sourceforge.net/" target="_blank">MagpieRSS</a> のバージョン';
$_lang['modx_version'] = 'MODxバージョン';
$_lang['onlineusers_action'] = 'アクション';
$_lang['onlineusers_actionid'] = 'アクションID';
$_lang['onlineusers_ipaddress'] = 'IPアドレス';
$_lang['onlineusers_lasthit'] = '最終アクセス';
$_lang['onlineusers_message'] = '直近20分以内のアクティブなユーザー一覧を表示しています。(現在時刻 ';
$_lang['onlineusers_title'] = 'オンラインユーザー';
$_lang['onlineusers_user'] = 'ユーザー';
$_lang['onlineusers_userid'] = 'ユーザーID';
$_lang['optimize_table'] = 'このテーブルを最適化するにはここをクリック';
$_lang['optimize_table_err'] = 'テーブルの最適化失敗';
$_lang['phpmailer_version'] = '<a href="http://sourceforge.net/projects/phpmailer/" target="_blank">PHPMailer</a> のバージョン';
$_lang['server'] = 'サーバー';
$_lang['servertime'] = 'サーバー時刻';
$_lang['serveroffset'] = 'サーバーオフセット';
$_lang['smarty_version'] = '<a href="http://smarty.net/" target="_blank">Smarty</a> のバージョン';
$_lang['sysinfo_desc'] = 'システムに関する基本情報を閲覧できます。';
$_lang['view_sysinfo'] = 'システム情報';
$_lang['table_prefix'] = 'テーブル接頭辞';
$_lang['truncate_table'] = 'このテーブルの内容を全削除するにはここをクリック';
$_lang['truncate_table_err'] = 'テーブルの削除失敗';
$_lang['version_codename'] = 'コードネーム';

==> modx-2.3.3-pl-ja.zip: modx-2.3.3-pl-ja/core/lexicon/ja/system_info.inc.php <==
<?php
/**
 * System Info English lexicon topic
 *
 * @language en
 * @package modx
 * @subpackage lexicon
 */
$_lang['database_charset'] = 'データベース文字コード';
$_lang['database_name'] = 'データベース名';
$_lang['database_server'] = 'データベースサーバー';
$_lang['database_tables'] = 'テーブル一覧';
$_lang['database_optimize'] = 'データベース最適化';
$_lang['database_table_clickhere'] = 'ここをクリック';
$_lang['database_table_clickbackup'] = '選択したテーブルをバックアップ・ダウンロード';
$_lang['database_table_datasize'] = 'データサイズ';
$_lang['database_table_droptablestatements'] = 'DROP文を生成';
$_lang['database_table_effectivesize'] = '有効サイズ';
$_lang['database_table_indexsize'] = 'インデックス';
$_lang['database_table_overhead'] = 'オーバーヘッド';
$_lang['database_table_reserved'] = '予約済み';//sqlsrv
$_lang['database_table_records'] = '件数';
$_lang['database_table_tablename'] = 'テーブル名';
$_lang['database_table_totalsize'] = '合計サイズ';
$_lang['database_table_totals'] = '総計:';
$_lang['database_table_unused'] = '不使用';//sqlsrv
$_lang['database_type'] = 'データベースの種類';
$_lang['database_version'] = 'データベースのバージョン:';
$_lang['extjs_version'] = '<a href="http://extjs.com/" target="_blank">ExtJS</a> のバージョン';
$_lang['localtime'] = 'ローカル時刻';
$_lang['magpie_version'] = '<a href="http://magpierss.sourceforge.net/" target="_blank">MagpieRSS</a> のバージョン';
$_lang['modx_version'] = 'MODXのバージョン';
$_lang['onlineusers_action'] = 'アクション';
$_lang['onlineusers_actionid'] = 'アクションID';
$_lang['onlineusers_ipaddress'] = 'IPアドレス';
$_lang['onlineusers_lasthit'] = '最終アクセス';
$_lang['onlineusers_message'] = '直近20分以内のアクティブなユーザー一覧を表示しています。（現在時刻 ';
$_lang['onlineusers_title'] = 'オンラインユーザー';
$_lang['onlineusers_user'] = 'ユーザー';
$_lang['onlineusers_userid'] = 'ユーザーID';
$_lang['optimize_table'] = 'このテーブルを最適化するにはここをクリック';
$_lang['optimize_table_err'] = 'テーブルの最適化失敗';
$_lang['phpmailer_version'] = '<a href="https://github.com/PHPMailer/PHPMailer" target="_blank">PHPMailer</a> のバージョン';
$_lang['server'] = 'サーバー';
$_lang['servertime'] = 'サーバー時刻';
$_lang['serveroffset'] = 'サーバーオフセット';
$_lang['smarty_version'] = '<a href="http://smarty.net/" target="_blank">Smarty</a> のバージョン';
$_lang['sysinfo_desc'] = 'システムに関する基本情報を閲覧できます。';
$_lang['view_sysinfo'] = 'システム情報';
$_lang['table_prefix'] = 'テーブル接頭辞';
$_lang['truncate_table'] = 'このテーブルの内容を全削除するにはここをクリック';
$_lang['truncate_table_err'] = 'テーブルの削除失敗';
$_lang['version_codename'] = 'コードネーム';
